@@ -1,17 +1,18 @@
 package Data::ModeMerge;
 
-use 5.010001;
-use Moo;
+our $DATE = '2015-02-21'; # DATE
+our $VERSION = '0.32'; # VERSION
 
-use Data::Dumper;
-use Data::ModeMerge::Config;
+use 5.010001;
+use strict;
+use warnings;
+
+use Mo qw(build default);
 
 require Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT = qw(mode_merge);
 
-our $VERSION = '0.30'; # VERSION
-
 sub mode_merge {
     my ($l, $r, $config_vars) = @_;
     my $mm = __PACKAGE__->new(config => $config_vars);
@@ -32,6 +33,8 @@ has mem => (is => "rw", default => sub { {} }); # for handling circular refs. {k
 has cur_mem_key => (is => "rw"); # for handling circular refs. instead of passing around this as argument, we put it here.
 
 sub _dump {
+    require Data::Dumper;
+
     my ($self, $var) = @_;
     Data::Dumper->new([$var])->Indent(0)->Terse(1)->Sortkeys(1)->Dump;
 }
@@ -51,6 +54,8 @@ sub _in($$) {
 }
 
 sub BUILD {
+    require Data::ModeMerge::Config;
+
     my ($self, $args) = @_;
 
     if ($self->config) {
@@ -328,8 +333,8 @@ sub _merge {
     }
 }
 
-# returns 1 if a is included in b (e.g. [user => "steven"] in included in [user
-# => steven => "quota"], but [user => "rudi"] is not)
+# returns 1 if a is included in b (e.g. [user => "jajang"] in included in [user
+# => jajang => "quota"], but [user => "paijo"] is not)
 sub _path_is_included {
     my ($self, $p1, $p2) = @_;
     my $res = 1;
@@ -343,17 +348,19 @@ sub _path_is_included {
 1;
 # ABSTRACT: Merge two nested data structures, with merging modes and options
 
-
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Data::ModeMerge - Merge two nested data structures, with merging modes and options
 
 =head1 VERSION
 
-version 0.30
+This document describes version 0.32 of Data::ModeMerge (from Perl distribution Data-ModeMerge), released on 2015-02-21.
 
 =head1 SYNOPSIS
 
@@ -754,16 +761,31 @@ L<Hash::Merge>, L<Hash::Merge::Simple>
 L<Data::Schema> and L<Config::Tree> (among others, two modules which
 use Data::ModeMerge)
 
+=head1 HOMEPAGE
+
+Please visit the project's homepage at L<https://metacpan.org/release/Data-ModeMerge>.
+
+=head1 SOURCE
+
+Source repository is at L<https://github.com/sharyanto/perl-Data-ModeMerge>.
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Data-ModeMerge>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Steven Haryanto.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
